@@ -8,7 +8,7 @@ use Mojo::Redis::Cursor;
 use Mojo::Redis::Database;
 use Mojo::Redis::PubSub;
 
-our $VERSION = '3.13';
+our $VERSION = '3.14';
 
 $ENV{MOJO_REDIS_URL} ||= 'redis://localhost:6379';
 
@@ -32,7 +32,23 @@ has pubsub => sub {
 has url => sub { Mojo::URL->new($ENV{MOJO_REDIS_URL}) };
 
 # TODO: Should this attribute be public?
-has _blocking_connection => sub { shift->_connection(ioloop => Mojo::IOLoop->new) };
+sub _blocking_connection {
+  my $self = shift;
+
+  delete @$self{qw(blocking_connection pid queue)} unless ($self->{pid} //= $$) eq $$;    # Fork-safety
+
+  if (@_) {
+    $self->{blocking_connection} = shift;
+    return $self;
+  }
+
+  # Existing connection
+  return $self->{blocking_connection}->encoding($self->encoding)
+    if $self->{blocking_connection} and $self->{blocking_connection}->is_connected;
+
+  # New connection
+  return $self->{blocking_connection} = $self->_connection(ioloop => Mojo::IOLoop->new);
+}
 
 sub cache { Mojo::Redis::Cache->new(redis => shift, @_) }
 sub cursor { Mojo::Redis::Cursor->new(redis => shift, command => [@_ ? @_ : (scan => 0)]) }
@@ -62,7 +78,7 @@ sub _connection {
 
 sub _dequeue {
   my $self = shift;
-  delete @$self{qw(pid queue)} unless ($self->{pid} //= $$) eq $$;    # Fork-safety
+  delete @$self{qw(blocking_connection pid queue)} unless ($self->{pid} //= $$) eq $$;    # Fork-safety
 
   # Exsting connection
   while (my $conn = shift @{$self->{queue} || []}) { return $conn->encoding($self->encoding) if $conn->is_connected }
